/*Written by Clayton Thyne on 03/24/15.  The main goal is to match up COW/Polity/Gleditsch ccodes.
The main warning here is that this should be a first step, and you should check to make sure changes 
to match things up make sense.  For example, there might be a good reason that Polity used 2 ccodes for
Ethiopia, and maybe others are following Polity in doing so.  I don't know yet.  So, whenever you see
that the original ccodes don't match what I changed, don't blame me if I screwed something up.*/

/*create a dataset that compares COW, polity and Gleditsch*/
/*COW from http://www.correlatesofwar.org/data-sets/cow-country-codes*/
/*polity from http://www.systemicpeace.org/inscrdata.html*/
/*gleditsch from http://privatewww.essex.ac.uk/~ksg/exptradegdp.html*/

cd I:\et_cetera\tools_for_data\funky_ccodes

/*merge all 3 together*/
import excel "p4v2013.xls", sheet("p4v2013") firstrow clear /*polity*/
keep ccode country year
rename country country_polity
gen polity=1
sort ccode year
save "polity_to_merge.dta", replace
import delimited "system2011.csv", clear  /*COW*/
keep ccode stateabb year
rename stateabb stateabb_COW
gen cow=1
sort ccode year
save "cow_to_merge.dta", replace
import delimited "gdpv6.txt", clear /*gleditsch*/
keep statenum stateid year
rename statenum ccode
rename stateid stateid_gled
gen gleditsch=1
sort ccode year
save "gled_to_merge.dta", replace
use "polity_to_merge.dta", clear
merge ccode year using "cow_to_merge.dta"
rename _mer _mer_polity_cow
sort ccode year
merge ccode year using "gled_to_merge.dta"
rename _merge _mer_polity_gled
sort ccode year
keep if year>=1945 /*decided to just look at post-WWII*/
order ccode country_polity stateabb_COW stateid_gled polity cow gleditsch
save "funky_ccodes.dta", replace

/*check for duplicates or missing state/years*/
use "funky_ccodes.dta", clear
keep if polity==1
br if ccode==ccode[_n-1] & year~=year[_n-1]+1 
/*Polity funky years:
255, Germany, 1945, 1990-2013*/
use "funky_ccodes.dta", clear
keep if cow==1
br if ccode==ccode[_n-1] & year~=year[_n-1]+1 
/*COW funky years:
255, Germany, 1945, 1990-2011
652, Syria, 1946-1958, 1961-2011
740, Japan, 1945, 1952-2011*/
use "funky_ccodes.dta", clear
keep if gled==1
br if ccode==ccode[_n-1] & year~=year[_n-1]+1
/*no funky gled years*/
/*Nothing really needs changed with theses.  They're all reasonable codings at this point*/

/*check for inconsistent coding*/
use "funky_ccodes.dta", clear
sort ccode year
/*Germany...
Polity: 							COW:							Gleditsch:
'Germany', 255, 1945, 1990-2013		'GMY', 255, 1945, 1990-2011
'Germany West', 260, 1945-1990		'GFR', 260, 1955-1990			'GFR', 260, 1950-2011
'Germany East', 265, 1945-1990		'GDR', 265, 1954-1990			'GDR', 265, 1950-1990
So, it looks like the funky thing here is that Gled isn't differentiating between Germany and West Germany during
Cold War.  Fix that with...*/
use "gled_to_merge.dta", clear
gen gled_og_ccode=ccode
replace ccode=255 if ccode==260 & year>1990
sort ccode year
/*Now...
Gleditsch: 	'GFR', 255, 1991-2011				'GFR', 260, 1950-1990				'GDR', 265, 1950-1990*/
save "gled_to_merge.dta", replace
use "funky_ccodes.dta", clear
drop _mer_polity_gled gleditsch stateid_gled
sort ccode year
merge ccode year using "gled_to_merge.dta"
order ccode country_polity stateabb_COW stateid_gled polity cow gleditsch
drop if polity==. & cow==. & gleditsch==.
sort ccode year
save "funky_ccodes.dta", replace

/*Yugoslavia								
Polity:										COW:						Gleditsch:
'Kosovo', 341, 2008-2013					'KOS', 347, 2008-2011		'KOS', 347, 2008-2011
'Serbia', 342, 2006-2013												'SER', 340, 2006-2011
'Yugoslavia', 345, 1945-1991				'YUG', 345, 1945-2011		'YUG', 345, 1950-2006
'Yugoslavia', 347, 1991-2002	
'Serbia and Montenegro', 347, 2003-2006
'Montenegro', 348, 2006-2013				'MNG', 341, 2006-2011		'MNG', 341, 2006-2011
Many funky things...
1. Polity is using 341 instead of 347 for Kosovo; change that when you use Polity
2. Polity is using 348 instead of 341 for Montenegro; change that when you use Polity
3. Polity adds a second ccode for Yugoslavia for some reason; change that (replace 347 with 345)
4. Polity and Gled aren't agreeing on what to number Serbia, 2006-2011; go with Polity (change Gled 340 to 342)
5. Nobody is quite sure what to do w/ Yugoslavia->Serbia and Montenegro -> Serbia/Montenegro; follow Gleditsch; so, we should have...
Yugoslavia, 345, 1945-2006 -> 	Serbia, 342, 2006-2013
								and
								Montenegro, 341, 2006-2011
Fix this for COW with..
replace ccode=342 if ccode==345 & year>=2006
Fix this for Polity with...
replace ccode=345 if country=="Serbia and Montenegro"

Making those changes, the table should become...																	
Polity:										COW:						Gleditsch:
'Kosovo', 347, 2008-2013					'KOS', 347, 2008-2011		'KOS', 347, 2008-2011
'Serbia', 342, 2006-2013					342, 2006-2011				'SER', 342, 2006-2011
'Yugoslavia', 345, 1945-2006				'YUG', 345, 1945-2005		'YUG', 345, 1950-2006
'Montenegro', 341, 2006-2013				'MNG', 341, 2006-2011		'MNG', 341, 2006-2011
*/

use "polity_to_merge.dta", clear
gen polity_og_ccode=ccode
replace ccode=347 if ccode==341
replace ccode=341 if ccode==348
replace ccode=345 if country=="Serbia and Montenegro"
replace ccode=345 if country=="Yugoslavia"
sort ccode year
drop if ccode==ccode[_n-1] & year==year[_n-1]
save "polity_to_merge.dta", replace
use "cow_to_merge.dta", clear
gen cow_og_ccode=ccode
replace ccode=342 if ccode==345 & year>=2006
sort ccode year
save "cow_to_merge.dta", replace
use "gled_to_merge.dta", clear
replace ccode=342 if ccode==340
sort ccode year
save "gled_to_merge.dta", replace
merge ccode year using "polity_to_merge.dta" "cow_to_merge.dta"
drop _mer*
order ccode country_polity stateabb_COW stateid_gled polity cow gleditsch
keep if year>=1945
sort ccode year
sum if ccode==ccode[_n-1] & year==year[_n-1]
list if ccode==ccode[_n-1] & year~=year[_n-1]+1 /*just germany, so we're fine*/
sort ccode year
save "funky_ccodes.dta", replace

/*USSR/Russia...
Polity:						COW:					Gleditsch:
'USSR', 364, 1945-1991		'RUS', 365, 1945-2011	'RUS', 365, 1950-2011
'Russia', 365, 1992-2013
Easy fix: replace polity 364 with 365*/
use "polity_to_merge.dta", clear
replace ccode=365 if ccode==364
sort ccode year
save "polity_to_merge.dta", replace
use "funky_ccodes.dta", clear
drop country_polity polity polity_og_ccode
merge ccode year using "polity_to_merge.dta"
drop _mer
order ccode country_polity stateabb_COW stateid_gled polity cow gleditsch
drop if polity==. & cow==. & gleditsch==.
keep if year>=1945
sort ccode year
sum if ccode==ccode[_n-1] & year==year[_n-1]
list if ccode==ccode[_n-1] & year~=year[_n-1]+1 /*just german, so we're fine*/
save "funky_ccodes.dta", replace

/*Ethiopia...
Polity:							COW:					Gleditsch:
'Ethiopia', 529, 1993-2003		'ETH', 530, 1945-2011	'ETH', 530, 1950-2011
'Ethiopia', 530, 1945-1993
Easy fix: replace polity 529 with 530, remove duplicate it will create*/
use "polity_to_merge.dta", clear
replace ccode=530 if ccode==529
sort ccode year
drop if ccode==ccode[_n-1] & year==year[_n-1]
save "polity_to_merge.dta", replace
use "funky_ccodes.dta", clear
drop country_polity polity polity_og_ccode
merge ccode year using "polity_to_merge.dta"
drop _mer
order ccode country_polity stateabb_COW stateid_gled polity cow gleditsch
drop if polity==. & cow==. & gleditsch==.
keep if year>=1945
sort ccode year
sum if ccode==ccode[_n-1] & year==year[_n-1]
list if ccode==ccode[_n-1] & year~=year[_n-1]+1 /*just german, so we're fine*/
save "funky_ccodes.dta", replace

/*Yemen...
Polity:								COW:						Gleditsch:
'Yemen North', 678, 1945-1990		'YAR', 678, 1945-1990		
'Yemen', 679, 1990-2013				'YEM', 679, 1990-2011		'YEM', 678, 1950-2011
'Yemen South', 680, 1967-1990		'YPR', 680, 1967-1990		'YPR', 680, 1967-1990
Easy fix: replace 678 to 679 for Gled, 1990-2011*/
use "gled_to_merge.dta", clear
replace ccode=679 if ccode==678 & year>=1990
sort ccode year
save "gled_to_merge.dta", replace
use "funky_ccodes.dta", clear
drop stateid_gled gleditsch gled_og_ccode
merge ccode year using "gled_to_merge.dta"
drop _mer
order ccode country_polity stateabb_COW stateid_gled polity cow gleditsch
drop if polity==. & cow==. & gleditsch==.
keep if year>=1945
sort ccode year
sum if ccode==ccode[_n-1] & year==year[_n-1]
list if ccode==ccode[_n-1] & year~=year[_n-1]+1 /*just german, so we're fine*/
save "funky_ccodes.dta", replace

/*Pakistan...
Polity:								COW:						Gleditsch:
'Pakistan', 769, 1947-1971			'PAK', 770, 1947-2011		'PAK', 770, 1950-2011
'Pakistan', 770, 1972-2013			
Easy fix: replace polity=770 if polity==769*/
use "polity_to_merge.dta", clear
replace ccode=770 if ccode==769
sort ccode year
drop if ccode==ccode[_n-1] & year==year[_n-1]
save "polity_to_merge.dta", replace
use "funky_ccodes.dta", clear
drop country_polity polity polity_og_ccode
merge ccode year using "polity_to_merge.dta"
drop _mer
order ccode country_polity stateabb_COW stateid_gled polity cow gleditsch
drop if polity==. & cow==. & gleditsch==.
keep if year>=1945
sort ccode year
sum if ccode==ccode[_n-1] & year==year[_n-1]
list if ccode==ccode[_n-1] & year~=year[_n-1]+1 /*just german, so we're fine*/
save "funky_ccodes.dta", replace

/*Vietnam...
Polity:								COW:						Gleditsch:
'Vietnam North', 816, 1954-1976		'DRV', 816, 1954-2011		'DRV', 816, 1954-2011
'Vietnam South', 817, 1955-1975		'RVN', 817, 1954-1975		'RVN', 817, 1954-1975
'Vietnam', 818, 1976-2013
Easy fix: replace polity=816 if polity==818, remove duplicate*/
use "polity_to_merge.dta", clear
replace ccode=816 if ccode==818
sort ccode year
drop if ccode==ccode[_n-1] & year==year[_n-1]
save "polity_to_merge.dta", replace
use "funky_ccodes.dta", clear
drop country_polity polity polity_og_ccode
merge ccode year using "polity_to_merge.dta"
drop _mer
order ccode country_polity stateabb_COW stateid_gled polity cow gleditsch
drop if polity==. & cow==. & gleditsch==.
keep if year>=1945
sort ccode year
sum if ccode==ccode[_n-1] & year==year[_n-1]
list if ccode==ccode[_n-1] & year~=year[_n-1]+1 /*just german, so we're fine*/
save "funky_ccodes.dta", replace

/*Kiribati and Nauru and others...
Polity:								COW:						Gleditsch:
									'VAN', 935, 1981-2011		'VAN', 935, 1980-2011
									'KIR', 946, 1999-2011		'KBI', 970, 1979-2011
									'TUV', 947, 2000-2011		'TUV', 973, 1978-2011
									'TON', 955, 1999-2011		'TON', 972, 1970-2011
									'NAU', 970, 1999-2011		'NAU', 971, 1968-2011
Make Gledistch consisten w/ COW*/
use "gled_to_merge.dta", clear
replace ccode=946 if state=="KBI"
replace ccode=947 if state=="TUV"
replace ccode=955 if state=="TON"
replace ccode=970 if state=="NAU"
sort ccode year
save "gled_to_merge.dta", replace
use "funky_ccodes.dta", clear
drop stateid_gled gleditsch gled_og_ccode
merge ccode year using "gled_to_merge.dta"
drop _mer
order ccode country_polity stateabb_COW stateid_gled polity cow gleditsch
drop if polity==. & cow==. & gleditsch==.
keep if year>=1945
sort ccode year
sum if ccode==ccode[_n-1] & year==year[_n-1]
list if ccode==ccode[_n-1] & year~=year[_n-1]+1 /*just german, so we're fine*/
save "funky_ccodes.dta", replace
